---
name: Feature Request
about: Tell us more of a great feature idea you have for Blankly 🚀
title: ''
labels: 'feature'
assignees: ''

---

## Description of Feature Request
A clear and concise description of what the feature request / idea is.

If possible, we'd also love a bulleted list of criteria to know that we've successfully implemented this feature.

## Why is it important?
Why is this feature request important for not just you, but for all the developers in our Blankly Community

## How would you use the feature?
Show us a code implementation of how you would like the feature to be used. 
(i.e. If it's a new strategy event, show us what inputs there would be)

## OPTIONAL: How would you implement this?
Give us some of your initial thoughts for implementing this. 

## Would you like to Contribute?

- [ ] Yes, I would love to contribute to this feature request 🎉
- [ ] No, but please keep me posted 🎉

**Additional Information**
Add any other context about the feature request here including what other packages have done, linked issues, and more. 
